@@ -47,7 +47,7 @@ typedef enum {
 	CALLBACK_GET_KEYRING_INFO,
 	CALLBACK_GET_ITEM_INFO,
 	CALLBACK_GET_ATTRIBUTES,
-	CALLBACK_GET_ACL,
+	CALLBACK_GET_ACL
 } KeyringCallbackType;
 
 typedef enum {
